@@ -47,7 +47,7 @@ test_that("@example does not introduce extra empty lines", {
     #' @example Rd-example-3.R
     NULL")[[1]]
 
-  expect_length(out$get_value("examples"), 2L)
+  expect_equal(str_count(out$get_value("examples"), "\n"), 1L)
 })
 
 test_that("@example gives warning if used instead of @examples", {
@@ -90,34 +90,23 @@ test_that("% in @examples escaped before matching braces test (#213)", {
 
 # escapes ------------------------------------------------------------------
 
-test_that("% and \\ in @example escaped", {
-  expect_equal(escape_examples("x %*% y # \\x"), rd("x \\%*\\% y # \\\\x"))
-})
-
-test_that("escapes within strings are not double escaped", {
+test_that("only % escaped in @examples", {
+  expect_equal(escape_examples("x %*% y"), rd("x \\%*\\% y"))
+  expect_equal(escape_examples("# \\x"), rd("# \\x"))
   expect_equal(escape_examples("'34.00\\'"), rd("'34.00\\'"))
 })
 
-test_that("\\dontrun etc. is not escaped #1", {
-  expect_equal(escape_examples("\\dontrun{x <- 1}"), rd("\\dontrun{x <- 1}"))
-
-  expect_equal(
-    escape_examples("\\dontrun{ \\{ x <- 1 \\} }"),
-    rd("\\dontrun{ \\{ x <- 1 \\} }")
-  )
-})
-
-test_that("\\dontrun etc. is not escaped #2", {
-  out <- roc_proc_text(rd_roclet(), "
+test_that("multi-line macros in @example", {
+  # https://github.com/r-lib/roxygen2/issues/974
+  out <- roxygen2:::roc_proc_text(roxygen2:::rd_roclet(), "
     #' @name a
     #' @title a
-    #' @examples
-    #' \\dontshow{ \\{ }
-    #' # Hidden!
-    #' \\dontshow{ \\} }
+    #'
+    #' @example Rd-example-4.txt
     NULL")[[1]]
 
-  verify_output(test_path("test-rd-examples-dotrun-escape.txt"), {
-    out$get_section("examples")
-  })
+  expect_equal(
+    format(out$get_section("examples")),
+    "\\examples{\n\\dontrun{\n1 + 1\n}\n}"
+  )
 })
